from .toolbox import configure_djangoapp_plugin


VERSION = (1, 2, 0)
"""Application version number tuple."""

VERSION_STR = '.'.join(map(str, VERSION))
"""Application version number string."""